use std::io;
use std::thread;
use std::pin::Pin;
use std::task::{Context, Poll};

use termion::event::Key;
use termion::input::TermRead;

use futures::Stream;
use futures::channel::mpsc;
use futures::SinkExt;

pub struct Inputs {
    rx: mpsc::Receiver<Key>,
    hndl: thread::JoinHandle<()>,
}

impl Inputs {
    pub fn new() -> Self {
        let (mut tx, rx) = mpsc::channel(64);

        let hndl = thread::spawn(move || {
            let stdin = io::stdin();
            let keys = stdin.keys();
            for key in keys {
                if key.is_err() {
                    break;
                }
                if let Err(_) = smol::block_on(tx.send(key.unwrap())) {
                    break; // and thus stop the thread
                }
            }
        });

        Self { rx, hndl }
    }
}

impl Stream for Inputs {
    type Item = Key;

    fn poll_next(mut self: Pin<&mut Self>, cx: &mut Context) -> Poll<Option<Self::Item>> {
        Pin::new(&mut self.rx).poll_next(cx)
    }
}
