use tui::{
    backend::Backend,
    layout::{Layout, Direction, Constraint, Rect},
    widgets::{Paragraph, Block, Borders},
    Frame,
};

use crate::app::SuteState;

pub fn draw_ui<B: Backend>(f: &mut Frame<B>, app: &mut SuteState) {
    let outer_layout = Layout::default()
        .direction(Direction::Vertical)
        .constraints([
                Constraint::Length(6),
                Constraint::Min(1),
                Constraint::Length(3),
            ].as_ref(),
        )
        .split(f.size());

    draw_header(f, app, outer_layout[0]);
    draw_main(f, app, outer_layout[1]);
    draw_command_line(f, app, outer_layout[2]);
}

fn draw_header<B: Backend>(f: &mut Frame<B>, app: &mut SuteState, layout_chunk: Rect) {
    f.render_widget(Block::default()
        .title("Header")
        .borders(Borders::ALL), layout_chunk);
}

fn draw_main<B: Backend>(f: &mut Frame<B>, app: &mut SuteState, layout_chunk: Rect) {
    let chunk = Layout::default()
        .direction(Direction::Horizontal)
        .constraints([Constraint::Percentage(20), Constraint::Percentage(80)].as_ref())
        .split(layout_chunk);

    f.render_widget(Paragraph::new(app.server.as_ref().map(|s| s.as_str()).unwrap_or("Not connected")), chunk[0]);
    f.render_widget(Paragraph::new("Main"), chunk[1]);
}

fn draw_command_line<B: Backend>(f: &mut Frame<B>, app: &mut SuteState, layout_chunk: Rect) {
    f.render_widget(Block::default()
        .title("Command line")
        .borders(Borders::ALL), layout_chunk);
    f.render_widget(Paragraph::new(">"), layout_chunk);
}
